@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
+from mock import call, Mock
 import pytest
 
-from mock import call, Mock
 from pyee import EventEmitter
-from pyee.uplift import uplift
+from pyee.uplift import unwrap, uplift
 
 
 class UpliftedEventEmitter(EventEmitter):
@@ -69,7 +69,7 @@ def test_uplift_emit():
     call_me.reset_mock()
 
     # Quick check for unwrap
-    uplifted_ee.unwrap()
+    unwrap(uplifted_ee)
 
     with pytest.raises(AttributeError):
         getattr(uplifted_ee, "unwrap")
@@ -102,7 +102,7 @@ def test_exception_handling(error_handling):
     base_ee = EventEmitter()
     uplifted_ee = uplift(UpliftedEventEmitter, base_ee, error_handling=error_handling)
 
-    # Exception handling alwyas prefers uplifted
+    # Exception handling always prefers uplifted
     base_error = Exception("base error")
     uplifted_error = Exception("uplifted error")
 
